Escritor class

Constructors

Escritor({required int id, required String nombre, required String genero, required String obra})

Properties

genero String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
nombre String
final
obra String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited